@@ -71,7 +71,7 @@ class Timer(statsd.Client):
                 return function(*args, **kwargs)
             finally:
                 # Stop the timer, send the message and cleanup
-                timer.stop(name)
+                timer.stop()
                 del timer
 
         return _decorator
